DirectLinkSuccess class

Successful direct link result

Inheritance
Available extensions

Constructors

DirectLinkSuccess({required String url, required Map<String, String> parameters, String? clickId})
Creates a new DirectLinkSuccess
const

Properties

clickId String?
Optional click ID
final
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, String>
URL parameters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL of the direct link
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited

Available on DirectLinkResult, provided by the DirectLinkResultExtension extension

Executes callback if result is no link
onSuccess(dynamic callback(DirectLinkSuccess)) → void

Available on DirectLinkResult, provided by the DirectLinkResultExtension extension

Executes callback if result is success
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited