CreateLinkResult class abstract
Abstract base class for create link results
- Implementers
Constructors
- CreateLinkResult()
-
Creates a new CreateLinkResult
const
- CreateLinkResult.error(String message)
-
Creates an error create link result
factory
- CreateLinkResult.success({required String shortUrl, required String code, String? qrCodeUrl})
-
Creates a successful create link result
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited