DeferredLinkResult class abstract
Result classes for different operations Abstract base class for deferred link results
- Implementers
- Available extensions
Constructors
- DeferredLinkResult()
-
Creates a new DeferredLinkResult
const
- DeferredLinkResult.error(String message)
-
Creates an error deferred link result
factory
- DeferredLinkResult.noMatch()
-
Creates a no match deferred link result
factory
-
DeferredLinkResult.success({required String deepLink, required String clickId, required double confidence, required bool matched, required Map<
String, dynamic> customData, required String matchMethod}) -
Creates a successful deferred link result
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
dynamic callback(String)) → void -
Available on DeferredLinkResult, provided by the DeferredLinkResultExtension extension
Executes callback if result is error -
onNoMatch(
VoidCallback callback) → void -
Available on DeferredLinkResult, provided by the DeferredLinkResultExtension extension
Executes callback if result is no match -
onSuccess(
dynamic callback(DeferredLinkSuccess)) → void -
Available on DeferredLinkResult, provided by the DeferredLinkResultExtension extension
Executes callback if result is success -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited