DeferredLinkSuccess class
Successful deferred link result
- Inheritance
-
- Object
- DeferredLinkResult
- DeferredLinkSuccess
- Available extensions
Constructors
Properties
- clickId → String
-
The click ID associated with the link
final
- confidence → double
-
Confidence score for the match
final
-
customData
→ Map<
String, dynamic> -
Custom data associated with the link
final
- deepLink → String
-
The deep link URL
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matched → bool
-
Whether a match was found
final
- matchMethod → String
-
Method used for matching
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
dynamic callback(String)) → void -
Available on DeferredLinkResult, provided by the DeferredLinkResultExtension extension
Executes callback if result is error -
onNoMatch(
VoidCallback callback) → void -
Available on DeferredLinkResult, provided by the DeferredLinkResultExtension extension
Executes callback if result is no match -
onSuccess(
dynamic callback(DeferredLinkSuccess)) → void -
Available on DeferredLinkResult, provided by the DeferredLinkResultExtension extension
Executes callback if result is success -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited